Orange Canvas Core
==================

.. image:: https://github.com/biolab/orange-canvas-core/workflows/Run%20tests/badge.svg
   :target: https://github.com/biolab/orange-canvas-core/actions?query=workflow%3A%22Run+tests%22
   :alt: Github Actions CI Build Status

.. image:: https://readthedocs.org/projects/orange-canvas-core/badge/?version=latest
   :target: https://orange-canvas-core.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Orange Canvas Core is a framework for building graphical user
interfaces for editing workflows. It is a component used to build
the Orange Canvas (http://orange.biolab.si) data-mining application
(for which it was developed in the first place).


Installation
------------

Orange Canvas Core is pip installable (https://pip.pypa.io/), simply run::

    pip install orange-canvas-core

Or use the::

    pip install ./

to install from the sources.

Documentation
-------------

Some incomplete documentation is available at https://orange-canvas-core.readthedocs.io
